@@ -3,11 +3,13 @@
 # Tests for XlsxWriter.
 #
 # SPDX-License-Identifier: BSD-2-Clause
-# Copyright (c), 2013-2023, John McNamara, jmcnamara@cpan.org
+#
+# Copyright (c), 2013-2025, John McNamara, jmcnamara@cpan.org
 #
 
+from xlsxwriter.workbook import Workbook
+
 from ..excel_comparison_test import ExcelComparisonTest
-from ...workbook import Workbook
 
 
 class TestCompareXLSXFiles(ExcelComparisonTest):
@@ -17,8 +19,7 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
     """
 
     def setUp(self):
-
-        self.set_filename('image32.xlsx')
+        self.set_filename("image32.xlsx")
 
     def test_create_file(self):
         """Test the creation of a simple XlsxWriter file with image(s)."""
@@ -27,7 +28,9 @@ class TestCompareXLSXFiles(ExcelComparisonTest):
 
         worksheet = workbook.add_worksheet()
 
-        worksheet.insert_image('B2', self.image_dir + 'red.png', {'x_offset': -100, 'y_offset': -100})
+        worksheet.insert_image(
+            "B2", self.image_dir + "red.png", {"x_offset": -100, "y_offset": -100}
+        )
 
         workbook.close()
 
